% clc
clear system
clear options
clear sequence


%system
system.nu01=1.5;  % resonance frequency in GHz in the AWG frame
system.sqn1=7/2;% spin quantum number
system.D=0.1;   % ZFS parameters in GHz
system.E=0.01;  
system.phi=0;   % orientation of the crystal
system.theta=pi;%
system.init_state=[0 0 1];      % magnetization vector for initials state

options.relaxation=0; % relaxation is switched off
options.det_op={'Sz12','Sz23','Sz34','Sz45','Sz56','Sz67','Sz78'}; % detection operators
options.LO=8;  % frequency of the local oscillator, to upconvert to lab frame
options.labframe=0; % tells SPIDYAN whether to simulate in lab frame or not

sequence.tp=[2048 2048];  % length of the pulses in ns [1st_pulse 2nd_pulse]
sequence.nu1=[4 4];  % microwave amplitude of the pulses [1st_pulse 2nd_pulse]
sequence.frq={[1.2 1.35] [1.8 1.65]}; % initial and final frequencies for linear chirps


% processing
[experiment,options] = triple(sequence, options);   % builds pulses

[system, state, options]=setup(system,options);   % builds system

[state, detected_signal, experiment, options, tables]=homerun(state,system,experiment, options, []); % propagates system


figure(1),clf
title('Polarization on detected transitions')
hold on
box on
plot(experiment.taxis,real(detected_signal.dc))
legend(options.det_op,'Location','NorthWest')
xlabel('t [ns]')
ylabel('<S_q>')
