% clear all
clear system
clear sequence
clear options

% This is the spinsystem
system.nu01=1;      % resonance frequency of the first spin in the LO-frame in GHz
system.sqn1=0.5;    % spin quantum number of first spin
system.T1=1000;     % relaxation times in ns
system.T2=500;      
system.init_state=[0 0 1]; % initial state, given as magnetization vector

% This is the pulse sequence
sequence.tp=120;        % length of the pulse in ns
sequence.nu1=25;        % pulse strength in MHz, for flipangle use sequence.beta(1)=pi;
sequence.beta=0;        % flip angle for pulse, sequence.nu1 has higher priority and therefore needs to be zero for beta to work
sequence.Q=0;           % critical adiabaticity, sequence.nu1 and sequence.beta need to be zero
sequence.frq={[0.75 1.25]};   % initial and final frequency of the chirp
sequence.t_rise=10;         % rise time of the pulse

% This block controls other parameters of the simulation
options.relaxation=0;   % tells SPIDYAN whether to include relaxation (1) or not (0)
options.down_conversion=1;    % downconversion of signal (1) or not (2)
options.cutoff_freq=300;% cut off frequency of the filter for downconversion in MHz
options.det_op={'-Sz'}; % cell-array with strings of detection operators
options.no_dc={};     % can be used to exclude certain signals from downconversion
options.no_detection=[];% can be used to exclude certain events from detection
options.direct_evolution=[]; % propagates indicated events in one step, only possible for free evolution
options.LO=8;           % frequency of the local oscillator
options.labframe=0;     % simulate in labframe on (1) or off (2)

options.awg.s_rate=4;  % sampling rate of AWG in GS/s, corresponds to time resolution

% Creates the pulse and other parameters required to run
[experiment, options] = triple(sequence, options);

% Creates Hamiltonian and initial state
[system, state0, options]=setup(system,options);

% Propagates the system
[state, detected_signal, experiment, options, tables]=homerun(state0, system, experiment, options, []);

% Display the final state
disp(state)

figure(1),clf % plots expectation values in simulation frame (AWG or lab frame)
title('Detected signal in the simulation frame')
hold on
box on
plot(detected_signal.t,real(detected_signal.sf))
xlabel('t [ns]')
ylabel('<S_q>')
legend(options.det_op)

figure(2),clf % plots expectation value after downconversion
title('Detected signal after down conversion')
hold on
box on
plot(detected_signal.t,real(detected_signal.dc)) % plots expectation value in labfram
xlabel('t [ns]')
ylabel('<S_q>')
legend(options.det_op)