clear system
clear options
clear sequence

% the spectral sampling
c=1;   % center frequency of Gaussian distribution of spins, in GHz
g=0.05; % width of the Gaussian distribution in GHz
nu0_s=0.9; % starting value for sampling of Gaussian distribution
nu0_e=1.1; % final value for sampling of Gaussian distribution
st=0.0005; % stepsize for sampling of Gaussian distribution
nu0_vec=nu0_s:st:nu0_e; % creates vector with resonance frequencies, according to above
p=exp(-((c-nu0_vec)/g).^2); % probabilities for each spin

% the system
system.sqn1=0.5;   % spin quantum number of first spin
system.sqn2=0.5;   % spin quantum number of second spin
system.nu02=-0.014; % resonance frequency of the second spin in GHz
system.A=0.014; % secular hyper fine coupling constant in GHz
system.B=0.009; % pseudo secular hyperfiner coupling constant in GHz
system.T1=[0,10000,5000,5000;0 0 5000 5000; 0 0 0 10000; 0 0 0 0]; % relaxation times in ns in matrix form (see documentation)
system.T2=[0,5000,1000,1000;0 0 1000 1000; 0 0 0 5000; 0 0 0 0];
system.init_state=[0 0 1]; % initial state

% the options
options.relaxation=0; % tells SPIDYAN whether to include relaxation (1) or not (0)
options.down_conversion=1;    % downconversion of signal (1) or not (2)
options.det_op={'S1p'};  % detection operator

% the sequence
sequence.tp=[200,100,100,500]; % vector with event lengths in ns
sequence.beta(1)=pi/2; % flip angle for first event, tells SPIDYAN that 1st event is a pulse
sequence.beta(3)=pi; % flip angle for second event, tells SPIDYAN that 2nd event is a pulse
sequence.frq={[0.5 1.5]}; % initial and final frequency of the chirp

[experiment,options] = triple(sequence, options); % builds experiment (pulses)

signalc=cell(1,length(nu0_vec)); % creates an empty cell to store results


parfor k=1:length(nu0_vec)
    
    systeml=system; % copy system into loop
    systeml.nu01=nu0_vec(k); % load resonance frequency 
    experimentl=experiment; % copy experiment structure into loop
       
    [systeml, state, optionsl]=setup(systeml,options); % build system 
    
    [state, detected_signal, experimentl]=homerun(state,systeml,experimentl, optionsl);  % propagate
    
    signalc{k}=detected_signal.sf;   % keep signals in simulation frame
end

signal=zeros(size(signalc{1})); % creates empty signal
t=linspace(0,sum(experiment.tp),length(signal)); % creates time axis

for k=1:length(nu0_vec)
    signal=signal+signalc{k}*p(k);   % merges all signals into one
end

figure(1); clf; plot(real(signal)) 
title('Signal in simulation frame')
xlabel('time [ns]')
ylabel('<S_{1p}>')

signaldc=strike(signal, t, c, options);   % down conversion of merged signals
signaldc=signaldc/max(max(signaldc));

figure(2); clf; 
title('Signal after down conversion')
hold on
plot(t,real(signaldc))
xlabel('time [ns]')
ylabel('<S_{1p}>')
plot([experiment.tp(1) experiment.tp(1)],[-1 1],'r--')
plot([experiment.tp(2)+experiment.tp(1) experiment.tp(2)+experiment.tp(1)],[-1 1],'r--')
plot([experiment.tp(3)+experiment.tp(2)+experiment.tp(1) experiment.tp(3)+experiment.tp(1)+experiment.tp(2)],[-1 1],'r--')



