% clear all
clear system
clear sequence
clear options

% This is the spinsystem
system.nu01=1;      % resonance frequency in the LO-frame
system.sqn1=0.5;    % spin quantum number
system.T1=1000;     % relaxation times in ns
system.T2=500;
system.init_state=[0 0 1]; % initial state, given as magnetization vector

% This is the pulse sequence
sequence.tp=100;       % length of the pulse in ns
sequence.nu1=0;        % pulse strength in MHz, for flipangle use sequence.beta(1)=pi;
sequence.frq={[0.8 1.2]};  % initial and final frequency of the chirp
sequence.t_rise=0;         % rise time of the pulse
sequence.beta=pi;          % define flipangle, only possible if no nu1
sequence.Q=0;              % define Q, only possible if no nu1 and no beta


% This block controls other parameters of the simulation
options.relaxation=0;   % tells SPIDYAN whether to include relaxation or not
options.down_conversion=1;    % downconversion of signal
options.cutoff_freq=300;% cut off frequency of the filter for downconversion in MHz
options.det_op={'-Sz'}; % cell-array with strings of detection operators
options.no_dc={2};     % can be used to exclude certain signals from downconversion
options.no_detection=[];% can be used to exclude certain events from detection
options.direct_evolution=[];
options.LO=8;           % frequency of the local oscillator
options.labframe=0;     % simulate in labframe on or off
options.complex_excitation=0; % complex excitation on or off

options.awg.s_rate=4;  % sampling rate of AWG in GS/s, corresponds to time resolution

options.resonator.active=0; % tell SPIDYAN to use resonator
options.resonator.Ql=50;    % quality factor of resonator
options.resonator.f0=9;     % centerfrequency of resonator in GHz in labframe
options.resonator.s_rate=96; % sampling frequency
options.resonator.comp_bw=0; % use bandwidth compensation

% Creates the pulse and other parameters required to run
[experiment, options] = triple(sequence, options);

% Creates Hamiltonian and initial state
[system, state0, options]=setup(system,options);

% Propagates the system
[state, detected_signal, experiment, options, tables]=homerun(state0, system, experiment, options, []);

% Display the final state
disp(state)

figure(1),clf
hold on
box on
plot(detected_signal.t,real(detected_signal.dc))
xlabel('t [ns]')
ylabel('<S_q>')
legend(options.det_op)

pulse_t=experiment.pulse{1}.binary;    % pulse in time domain

figure(2),clf % plots pulse in time domain
title('Pulse in the time domain')
xlabel('t [ns]')
ylabel('Int. [a. u.]')
hold on
plot(experiment.taxis(2:end),real(pulse_t))

pulse_f=fftshift(fft(experiment.pulse{1}.binary-mean(experiment.pulse{1}.binary))); % FFT of pulse
df=options.awg.s_rate/length(pulse_f); 
f=linspace(-options.awg.s_rate+df,options.awg.s_rate,length(pulse_f)); % frequency axis

figure(3),clf  % plots pulse in frequency domain
title('Pulse in the frequency domain')
xlabel('f [GHz]')
ylabel('Int. [a. u.]')
hold on
plot(f,abs(pulse_f))