% clear all
clear options
clear system
clear sequence

% Structure for the pulse experiment
sequence.tp=[50,20,40,40]; % vector with event lengths in ns
sequence.beta(1)=pi;  % flip angle for first event, tells SPIDYAN that 1st event is a pulse
sequence.beta(3)=pi/2; % flip angle for second event, tells SPIDYAN that 2nd event is a pulse
sequence.frq={[0.5 1.5]}; % initial and final frequency of the chirp
sequence.excite={[1 0],[],[1 0]};  % excitation of first spin only [1 0], both spins [1 1], 2nd spin [0 1], defined for each event
% sequence.pcycle{3}=[0, 1; pi/2, -1; pi, 1; 3*pi/2, -1]; 	% phasecycling on the second pulse = 3rd event

% structure options
options.relaxation=0; % tells SPIDYAN whether to include relaxation (1) or not (0)
options.det_op={'Sp','-Sz'}; % cell-array with strings of detection operators
options.down_conversion=1; % downconversion of signal (1) or not (2)
options.cutoff_freq=100; % cut off frequency of the filter for downconversion in MHz
options.no_dc={};  % can be used to exclude certain signals from downconversion
options.no_detection=[]; % can be used to exclude certain events from detection
options.direct_evolution=[2];  % propagates indicated events in one step, only possible for free evolution

%This command can be used to switch detection off during the delay and the second pulse.
% options.no_detection=[2,3];
%----------------------------

% structure for the spin system
system.nu01=1;      % resonance frequency of the first spin in the LO-frame in GHz
system.sqn1=0.5;    % spin quantum number
system.T1=1000;     % relaxation times in ns
system.T2=500;      
system.init_state=[0 0 1]; % initial state, given as magnetization vector

%Include this for the second example with the nucleus:
% system.sqn2=0.5;    % spin quantum number of the second spin
% system.nu02=-0.014; % resonance frequency of the second spin in GHz
% system.A=0.014;     % secular hyper fine coupling constant in GHz
% system.B=0.009;     % pseudo-secular hyper fine coupling constant in GHz
% options.det_op={'S1p', 'S1z','S2p'};  % new detection operators, adapted to a two spin system
% % options.no_dc={3}; %or options.no_filt={'S2p'};  excludes the third detected signal from being detected
%----------------------------------

% Processing of the input
[experiment, options] = triple(sequence, options);
[system, state, options]=setup(system, options);

%Proagation
[state, detected_signal, experiment, options]=homerun(state, system, experiment,options, []);

%plotting
figure(1),clf
title('Signal in simulation frame')
hold on
box on
plot(experiment.taxis,real(detected_signal.sf))
legend(options.det_op,'Location','NorthEast')

figure(2),clf
title('Signal after down conversion')
hold on
box on
plot(experiment.taxis,real(detected_signal.dc))
legend(options.det_op,'Location','NorthEast')
xlabel('t [ns]')
ylabel('<S_{q}>')