function [sops]=hitandrun(system)
% [sops]=hitandrun(system)
% 
% Function hitandrun creates the spin operators for a given spinsystem of
% maximal two spins. To create the spin operators hitandrun calls spop.
% 
% Input:
% system            structure with the spin system
% .sqn1             nuclear spin of the first spin
% .sqn2             optional, nuclear spin of the second spin
% .spins            number of spins in the spin system
%     
% Output:
% sops              structure which containing the spin operators for the
%                   given spinsystem (eg. Sx, Sy, Sz, Sp, Sm for one spin,
%                   S1z, S2z, Szz,... for two spins)
%
% St. Pribitzer, 2014

 
if  system.spins==1
    sops.Sx=spops(system.sqn1,'x');
    sops.Sy=spops(system.sqn1,'y');
    sops.Sz=spops(system.sqn1,'z');
    sops.Sp=spops(system.sqn1,'p');
    sops.Sm=spops(system.sqn1,'m');
    sops.E=spops(system.sqn1,'e');
else
    sops.S1x=spops([system.sqn1 system.sqn2],'xe');
    sops.S2x=spops([system.sqn1 system.sqn2],'ex');
    sops.S1y=spops([system.sqn1 system.sqn2],'ye');
    sops.S2y=spops([system.sqn1 system.sqn2],'ey');
    sops.S1z=spops([system.sqn1 system.sqn2],'ze');
    sops.S2z=spops([system.sqn1 system.sqn2],'ez');
    sops.Sxx=2*spops([system.sqn1 system.sqn2],'xx');
    sops.Syy=2*spops([system.sqn1 system.sqn2],'yy');
    sops.Szz=2*spops([system.sqn1 system.sqn2],'zz');
    sops.Sxy=2*spops([system.sqn1 system.sqn2],'xy');
    sops.Sxz=2*spops([system.sqn1 system.sqn2],'xz');
    sops.Syx=2*spops([system.sqn1 system.sqn2],'yx');
    sops.Szx=2*spops([system.sqn1 system.sqn2],'zx');
    sops.Syz=2*spops([system.sqn1 system.sqn2],'yz');
    sops.Szy=2*spops([system.sqn1 system.sqn2],'zy');
    sops.S1p=spops([system.sqn1 system.sqn2],'pe');
    sops.Spp=spops([system.sqn1 system.sqn2],'pp');
    sops.S1m=spops([system.sqn1 system.sqn2],'me');
    sops.S2p=spops([system.sqn1 system.sqn2],'ep');
    sops.S2m=spops([system.sqn1 system.sqn2],'em');
    sops.Smm=spops([system.sqn1 system.sqn2],'mm');
    sops.E=spops([system.sqn1 system.sqn2],'ee');
end

end